@@ -17,19 +17,23 @@
 
 #include "skyobjectname.h"
 
-SkyObjectName::SkyObjectName(const char *str, SkyObject *obj)
-	: skyobject (obj), Text ((const char *) str)
+#include <klocale.h>
+
+SkyObjectName::SkyObjectName( const QString &str, SkyObject *obj )
+	: skyobject ( obj ), Text ( str )
 {
-//	qDebug (Text);
 }
 
 SkyObjectName::~SkyObjectName(){
 }
 
-SkyObjectNameListItem::SkyObjectNameListItem (QListBox *parent, SkyObjectName *obj)
-	: QListBoxText (parent), object (obj)
+SkyObjectNameListItem::SkyObjectNameListItem ( QListBox *parent, SkyObjectName *obj, bool useLatinConstellNames )
+	: QListBoxText ( parent ), object ( obj )
 {
-	setText (obj->text());
+	if ( useLatinConstellNames )
+		setText ( obj->text() );
+	else
+		setText ( obj->translatedText() );
 }
 
 
